@@ -31,45 +31,45 @@ class AtomicInt(object):
 
     UINT64_MAX = 18446744073709551615
 
-    def __init__(self, initialValue=0, maximumValue=UINT64_MAX):
+    def __init__(self, initial_value=0, maximum_value=UINT64_MAX):
         """
         Init
-        :param initialValue: Initial value
-        :type initialValue: int
-        :param maximumValue: Maximum value (default : UINT64)
-        :type maximumValue: int
+        :param initial_value: Initial value
+        :type initial_value: int
+        :param maximum_value: Maximum value (default : UINT64)
+        :type maximum_value: int
         :return Nothing
         """
 
-        self._currentValue = initialValue
-        self._maximumValue = maximumValue
-        self._processMaxValue()
+        self._current_value = initial_value
+        self.maximum_value = maximum_value
+        self._process_max_value()
 
-    def increment(self, incrementValue=1):
+    def increment(self, increment_value=1):
         """
         Increment and return current value
-        :param incrementValue: Increment value
-        :type incrementValue: int
+        :param increment_value: Increment value
+        :type increment_value: int
         :return Current value
         :rtype int
         """
 
-        self._currentValue += incrementValue
-        self._processMaxValue()
-        return self._currentValue
+        self._current_value += increment_value
+        self._process_max_value()
+        return self._current_value
 
-    def set(self, currentValue):
+    def set(self, current_value):
         """
         Set current value
-        :param currentValue: New current value
-        :type currentValue: int
+        :param current_value: New current value
+        :type current_value: int
         :return Current value
         :rtype int
         """
 
-        self._currentValue = currentValue
-        self._processMaxValue()
-        return self._currentValue
+        self._current_value = current_value
+        self._process_max_value()
+        return self._current_value
 
     def get(self):
         """
@@ -77,25 +77,25 @@ class AtomicInt(object):
         :return Current value
         :rtype int
         """
-        return self._currentValue
+        return self._current_value
 
-    def _processMaxValue(self):
+    def _process_max_value(self):
         """
         Process max value if required
         :return Nothing
         """
 
-        if self._maximumValue and self._currentValue > self._maximumValue:
+        if self.maximum_value and self._current_value > self.maximum_value:
             # Compute & reset with reminder if maximum value reached
-            div = long(self._currentValue / self._maximumValue)
-            reminder = self._currentValue % self._maximumValue
+            div = long(self._current_value / self.maximum_value)
+            reminder = self._current_value % self.maximum_value
             if div > 0:
                 if reminder == 0:
-                    self._currentValue = self._maximumValue
+                    self._current_value = self.maximum_value
                 else:
-                    self._currentValue = reminder
+                    self._current_value = reminder
             else:
-                self._currentValue = reminder
+                self._current_value = reminder
 
 
 class AtomicIntSafe(AtomicInt):
@@ -103,43 +103,43 @@ class AtomicIntSafe(AtomicInt):
     Safe atomic integer with lock.
     """
 
-    def __init__(self, initialValue=0, maximumValue=AtomicInt.UINT64_MAX):
+    def __init__(self, initial_value=0, maximum_value=AtomicInt.UINT64_MAX):
         """
         Init
-        :param initialValue: Initial value
-        :type initialValue: int
-        :param maximumValue: Maximum value (default : UINT64)
-        :type maximumValue: int
+        :param initial_value: Initial value
+        :type initial_value: int
+        :param maximum_value: Maximum value (default : UINT64)
+        :type maximum_value: int
         :return Nothing
         """
 
         self._lock = Lock()
         with self._lock:
-            AtomicInt.__init__(self, initialValue, maximumValue)
+            AtomicInt.__init__(self, initial_value, maximum_value)
 
-    def increment(self, incrementValue=1):
+    def increment(self, increment_value=1):
         """
         Increment and return current value
-        :param incrementValue: Increment value
-        :type incrementValue: int
+        :param increment_value: Increment value
+        :type increment_value: int
         :return Current value
         :rtype int
         """
 
         with self._lock:
-            return AtomicInt.increment(self, incrementValue)
+            return AtomicInt.increment(self, increment_value)
 
-    def set(self, currentValue):
+    def set(self, current_value):
         """
         Set current value
-        :param currentValue: New current value
-        :type currentValue: int
+        :param current_value: New current value
+        :type current_value: int
         :return Current value
         :rtype int
         """
 
         with self._lock:
-            return AtomicInt.set(self, currentValue)
+            return AtomicInt.set(self, current_value)
 
     def get(self):
         """
