@@ -25,8 +25,10 @@ from collections import OrderedDict
 import logging
 from multiprocessing import Lock
 import sys
+
 from pythonsol.AtomicInt import AtomicInt
 
+
 logger = logging.getLogger("DelayToCount")
 
 
@@ -39,77 +41,77 @@ class DelayToCount(object):
     [...-...  ] => z hits
     """
 
-    def __init__(self, instanceName, delayArray=None):
+    def __init__(self, instance_name, ar_delay=None):
         """
         Init
-        :param delayArray: Delay array to handle in millis (must finish with max int value, value in increasing order)
-        :type delayArray: list,tuple,None
-        :param instanceName: Instance name
-        :type instanceName: str
+        :param ar_delay: Delay array to handle in millis (must finish with max int value, value in increasing order)
+        :type ar_delay: list,tuple,None
+        :param instance_name: Instance name
+        :type instance_name: str
         :return Nothing
         """
 
         # Default is required
-        if not delayArray:
-            delayArray = [0, 50, 100, 500, 1000, 2500, 5000, 10000, 30000, 60000, sys.maxint]
+        if not ar_delay:
+            ar_delay = [0, 50, 100, 500, 1000, 2500, 5000, 10000, 30000, 60000, sys.maxint]
 
         # Name
-        self._instanceName = instanceName
+        self._instance_name = instance_name
 
         # Hash (ordered)
-        self._sortedDict = OrderedDict()
+        self._sorted_dict = OrderedDict()
 
         # Validate max int at the end (otherwise we may not be able to process and store some values)
-        if delayArray[len(delayArray) - 1] != sys.maxint:
-            raise Exception("sys.maxint required in last delayArray item")
+        if ar_delay[len(ar_delay) - 1] != sys.maxint:
+            raise Exception("sys.maxint required in last ar_delay item")
 
         # Validate order and prepare the hash
         prev = None
-        for ms in delayArray:
+        for ms in ar_delay:
             if not prev:
                 prev = ms
             elif prev >= ms:
                 raise Exception("Not increasing value, prev={0}, ms={1}".format(prev, ms))
 
             # Hash it
-            self._sortedDict[ms] = AtomicInt()
+            self._sorted_dict[ms] = AtomicInt()
 
-    def put(self, delayMs, incrementValue=1):
+    def put(self, delay_ms, increment_value=1):
         """
         Put a value for specified delay.
-        :param delayMs: Delay in millis
-        :type delayMs: int
-        :param incrementValue: Value to increment
-        :type incrementValue: int
+        :param delay_ms: Delay in millis
+        :type delay_ms: int
+        :param increment_value: Value to increment
+        :type increment_value: int
         :return Nothing
         """
 
         # Found the good one
-        aif = self._sortedDict[sys.maxint]
-        for ms, ai in self._sortedDict.iteritems():
-            if ms <= delayMs and ms != sys.maxint:
+        aif = self._sorted_dict[sys.maxint]
+        for ms, ai in self._sorted_dict.iteritems():
+            if ms <= delay_ms and ms != sys.maxint:
                 aif = ai
             else:
                 break
 
         # Go
-        aif.increment(incrementValue)
+        aif.increment(increment_value)
 
     def log(self):
         """
         Write to logger
         """
 
-        ar = self._sortedDict.keys()
+        ar = self._sorted_dict.keys()
         for i in range(0, len(ar) - 1):
             ms1 = ar[i]
             ms2 = ar[i + 1]
             if ms2 == sys.maxint:
                 ms2 = "MAX"
-            ai = self._sortedDict[ms1]
+            ai = self._sorted_dict[ms1]
             logger.info("DTC [%s-%s], c=%s", ms1, ms2, ai.get())
 
-    def toDict(self):
+    def to_dict(self):
         """
         To dict
         :return OrderedDict
@@ -117,14 +119,14 @@ class DelayToCount(object):
         """
 
         d = OrderedDict()
-        ar = self._sortedDict.keys()
+        ar = self._sorted_dict.keys()
         for i in range(0, len(ar) - 1):
             ms1 = ar[i]
             ms2 = ar[i + 1]
             if ms2 == sys.maxint:
                 ms2 = "MAX"
-            ai = self._sortedDict[ms1]
-            out_k = "{0}|{1}-{2}".format(self._instanceName, ms1, ms2)
+            ai = self._sorted_dict[ms1]
+            out_k = "{0}|{1}-{2}".format(self._instance_name, ms1, ms2)
             out_v = ai.get()
             d[out_k] = out_v
         return d
@@ -139,32 +141,32 @@ class DelayToCountSafe(DelayToCount):
     [...-...  ] => z hits
     """
 
-    def __init__(self, instanceName, delayArray=None):
+    def __init__(self, instance_name, ar_delay=None):
         """
         Init
-        :param delayArray: Delay array to handle in millis (must finish with max int value, value in increasing order)
-        :type delayArray: list,tuple,None
-        :param instanceName: Instance name
-        :type instanceName: str
+        :param ar_delay: Delay array to handle in millis (must finish with max int value, value in increasing order)
+        :type ar_delay: list,tuple,None
+        :param instance_name: Instance name
+        :type instance_name: str
         :return Nothing
         """
 
         self._lock = Lock()
         with self._lock:
-            DelayToCount.__init__(self, instanceName, delayArray)
+            DelayToCount.__init__(self, instance_name, ar_delay)
 
-    def put(self, delayMs, incrementValue=1):
+    def put(self, delay_ms, increment_value=1):
         """
         Put a value for specified delay.
-        :param delayMs: Delay in millis
-        :type delayMs: int
-        :param incrementValue: Value to increment
-        :type incrementValue: int
+        :param delay_ms: Delay in millis
+        :type delay_ms: int
+        :param increment_value: Value to increment
+        :type increment_value: int
         :return Nothing
         """
 
         with self._lock:
-            DelayToCount.put(self, delayMs, incrementValue)
+            DelayToCount.put(self, delay_ms, increment_value)
 
     def log(self):
         """
@@ -173,19 +175,11 @@ class DelayToCountSafe(DelayToCount):
         with self._lock:
             DelayToCount.log(self)
 
-    def toDict(self):
+    def to_dict(self):
         """
         To dict
         :return OrderedDict
         :rtype: OrderedDict
         """
         with self._lock:
-            DelayToCount.toDict(self)
-
-
-
-
-
-
-
-
+            DelayToCount.to_dict(self)
