@@ -148,7 +148,7 @@ class SolBase(object):
 
         if compo_name:
             cls._compo_name = compo_name
-            lifecyclelogger.info("compo_name now set to=%s", cls._compo_name)
+            lifecyclelogger.debug("compo_name now set to=%s", cls._compo_name)
 
     @classmethod
     def get_compo_name(cls):
@@ -309,14 +309,14 @@ class SolBase(object):
                 return
 
             # Fire the voodoo magic :)
-            lifecyclelogger.info("Voodoo : gevent : entering, aggressive=%s", aggressive)
+            lifecyclelogger.debug("Voodoo : gevent : entering, aggressive=%s", aggressive)
             monkey.patch_all(aggressive=aggressive)
-            lifecyclelogger.info("Voodoo : gevent : entering")
+            lifecyclelogger.debug("Voodoo : gevent : entering")
 
             # Initialize log level to INFO
-            lifecyclelogger.info("Voodoo : logging : entering")
+            lifecyclelogger.debug("Voodoo : logging : entering")
             cls.logging_init()
-            lifecyclelogger.info("Voodoo : logging : done")
+            lifecyclelogger.debug("Voodoo : logging : done")
 
             # Done
             cls._voodoo_initialized = True
@@ -392,8 +392,13 @@ class SolBase(object):
 
             # Done
             cls._logging_initialized = True
-            lifecyclelogger.info("Logging : initialized from memory, log_level=%s, force_reset=%s", log_level,
-                                 force_reset)
+            if force_reset:
+                lifecyclelogger.info("Logging : initialized from memory, log_level=%s, force_reset=%s",
+                                     log_level, force_reset)
+            else:
+                lifecyclelogger.debug("Logging : initialized from memory, log_level=%s, force_reset=%s",
+                                      log_level, force_reset)
+
 
     @classmethod
     def logging_initfromfile(cls, config_file_name, force_reset=False):
@@ -416,7 +421,10 @@ class SolBase(object):
             try:
                 logger.debug("Logging : config_file_name=%s", config_file_name)
                 fileConfig(config_file_name, None, False)
-                lifecyclelogger.info("Logging : initialized from file, config_file_name=%s", config_file_name)
+                if force_reset:
+                    lifecyclelogger.info("Logging : initialized from file, config_file_name=%s", config_file_name)
+                else:
+                    lifecyclelogger.debug("Logging : initialized from file, config_file_name=%s", config_file_name)
             except Exception as e:
                 logger.error("Exception, e=%s", cls.extostr(e))
                 raise
@@ -443,7 +451,7 @@ class SolBase(object):
         :return Nothing
         """
 
-        logger.info("Switching _masterProcess to %s", b)
+        logger.debug("Switching _masterProcess to %s", b)
         cls._master_process = b
 
     #===============================
